@@ -6,10 +6,8 @@
 #include <truncnorm.h>
 #include <RcppArmadilloExtensions/sample.h>
 
-
 // [[Rcpp::depends(RcppArmadillo, RcppDist, RcppProgress)]]
 
-
 // mean of 3d array
 // [[Rcpp::export]]
 arma::mat mean_array(arma::cube x){
@@ -1163,8 +1161,8 @@ Rcpp::List mv_ordinal_cowles(arma::mat Y,
   // starting thresholds
   for(int i = 0; i < max(Y.col(0)) - 1; ++i){
     for(int j = 0; j < k; ++j){
-      thresh_mat(j, i + 2, 0) = R::qnorm5(sum(Y.col(j) <= thresh_sampled[i]) / n,
-                 -R::qnorm5(sum(Y.col(j) == 1) / n, 0, 1, TRUE, FALSE), 1, TRUE, FALSE);
+      thresh_mat(j, i + 2, 0) = R::qnorm(sum(Y.col(j) <= thresh_sampled[i]) / n,
+                 -R::qnorm(sum(Y.col(j) == 1) / n, 0, 1, TRUE, FALSE), 1, TRUE, FALSE);
     }
   }
 
@@ -1204,7 +1202,7 @@ Rcpp::List mv_ordinal_cowles(arma::mat Y,
     for(int i = 0; i < max(Y.col(0)) - 1; ++i){
       for(int j = 0; j < k ; ++j){
         arma::mat slice_c_thresh = thresh_mat.slice(0);
-        c_thresh_mat(j, i+2, 0) = R::qnorm5(R::runif(R::pnorm(0,  slice_c_thresh(j , thresh_sampled[i]), MH, TRUE, FALSE), 1),
+        c_thresh_mat(j, i+2, 0) = R::qnorm(R::runif(R::pnorm(0,  slice_c_thresh(j , thresh_sampled[i]), MH, TRUE, FALSE), 1),
                      slice_c_thresh(j , thresh_sampled[i]), MH, TRUE, FALSE);
       }
     }
@@ -1212,11 +1210,11 @@ Rcpp::List mv_ordinal_cowles(arma::mat Y,
     for(int j = 0; j < n; ++j){
       for(int i = 0; i < k; ++i){
 
-        R_numer(j, i) =  (R::pnorm5(c_thresh_mat(i , Y.col(i)[j], 0) - mm(j), 0, 1, TRUE, FALSE) -
-          R::pnorm5(c_thresh_mat(i , Y.col(i)[j]-1 , 0) - mm(j), 0, 1, TRUE, FALSE));
+        R_numer(j, i) =  (R::pnorm(c_thresh_mat(i , Y.col(i)[j], 0) - mm(j), 0, 1, TRUE, FALSE) -
+          R::pnorm(c_thresh_mat(i , Y.col(i)[j]-1 , 0) - mm(j), 0, 1, TRUE, FALSE));
 
-        R_denom(j, i) = (R::pnorm5(thresh_mat(i , Y.col(i)[j], 0) - mm(j), 0, 1, TRUE, FALSE) -
-          R::pnorm5(thresh_mat(i , Y.col(i)[j]-1, 0) - mm(j), 0, 1, TRUE, FALSE));
+        R_denom(j, i) = (R::pnorm(thresh_mat(i , Y.col(i)[j], 0) - mm(j), 0, 1, TRUE, FALSE) -
+          R::pnorm(thresh_mat(i , Y.col(i)[j]-1, 0) - mm(j), 0, 1, TRUE, FALSE));
       }
     }
 
@@ -2396,6 +2394,7 @@ double bic_fast(arma::mat Theta, arma::mat S, double n, float prior_prob){
   double neg_ll =  -2 * ((n*0.5) * (log(det(Theta)) - trace(S * Theta)));
 
   double bic = neg_ll + (nonzero.n_elem * log(n) - (nonzero.n_elem * log(prior_prob / (1 - prior_prob))));
+
   return bic;
 }
 
@@ -2412,10 +2411,11 @@ Rcpp::List find_ids(arma::mat x){
   ret["nonzero"] = nonzero;
   ret["zero"] = zero;
   return ret;
-
-
 }
 
+// Search for possible graphs, accepting if BIC_new is better than BIC_old
+// MH algo does not work probabilistically - accept only better, never worse.
+// Revisit this function 
 // [[Rcpp::export]]
 Rcpp::List search(arma::mat S,
                   float iter,
@@ -2426,80 +2426,91 @@ Rcpp::List search(arma::mat S,
                   int stop_early,
                   bool progress){
 
-
   Progress  pr(iter, progress);
 
   int p = S.n_cols;
 
   arma::cube adj(p, p, iter);
+  
+  // Copy start_adj to adj_s
+  arma::mat adj_s = start_adj; 
 
-  arma::mat adj_s = start_adj;
-
-  Rcpp::List start =  find_ids(start_adj);
-
+  // Create start object containing position of zero and nonzeros
+  Rcpp::List start = find_ids(start_adj);
+  
   arma::uvec zeros = start["zero"];
   arma::uvec nonzeros = start["nonzero"];
 
-  arma::mat adj_mat(p,p);
-
-  arma::mat mat_old = adj_mat;
-
+  // Use adj_start from R
+  arma::mat mat_old = start_adj;
+  // Initialize adj_mat to match mat_old
+  arma::mat adj_mat = mat_old;    
+  
+  // initialize vectors
   arma::vec bics(iter, arma::fill::zeros);
-
   arma::vec acc(1, arma::fill::zeros);
-
   arma::vec repeats(1, arma::fill::zeros);
-
+ 
+  // Loop through iterations
   for(int s = 0; s < iter; ++s){
 
+    // Incrementing progress bar
     pr.increment();
 
+    // Catch user abort key
     if (s % 250 == 0){
       Rcpp::checkUserInterrupt();
     }
-
+    
     adj_s = mat_old;
 
+    // Flip one edge at a time
     if (s % 2 == 0){
       arma::vec id_add = Rcpp::RcppArmadillo::sample(arma::conv_to<arma::vec>::from(zeros), 1, false);
       adj_s.elem(arma::conv_to<arma::uvec>::from(id_add)).fill(1);
-      adj_mat = symmatu(adj_s);
-      adj_mat.diag().fill(1);
-
     } else {
       arma::vec id_add = Rcpp::RcppArmadillo::sample(arma::conv_to<arma::vec>::from(nonzeros), 1, false);
       adj_s.elem(arma::conv_to<arma::uvec>::from(id_add)).fill(0);
-      adj_mat = symmatu(adj_s);
-      adj_mat.diag().fill(1);
     }
 
+    // Ensure that adj_mat is symmetric
+    adj_mat = symmatu(adj_s);
+    adj_mat.diag().fill(1);
+    
+    // Run the hft_algorithm and compute the BIC
     Rcpp::List fit1 = hft_algorithm(S, adj_mat, 0.00001, 10);
     arma::mat  Theta = fit1["Theta"];
     double new_bic = bic_fast(Theta, S, n, gamma);
+    
+    // Specifically compute delta to facilitate debugging
+    double delta =  new_bic - old_bic;
 
-    if(exp(-0.5 * (new_bic - old_bic)) > 1){
+    // Generate a random uniform number for probabilistic acceptance
+    // double random_uniform = arma::randu();
+
+    // Metropolis-Hastings acceptance criterion
+    if(exp(-0.5 *  delta ) >= 1) { //random_uniform ){
+      // go back to >=1, as accepting probabilistically has BIC creep up for unknown reason
       mat_old = adj_mat;
       adj.slice(s) = adj_mat;
       old_bic = new_bic;
-      acc(0) = acc(0) + 1;
-      Rcpp::List start =  find_ids(start_adj);
+      acc(0)++;
+      repeats(0) = 0;
+      Rcpp::List start =  find_ids(adj_mat);
       arma::uvec zeros = start["zero"];
       arma::uvec nonzeros = start["nonzero"];
-
-      repeats(0) = 0;
-
     } else {
-
-      adj.slice(s) = adj_s;
-      repeats(0) = repeats(0) + 1;
-
+      adj.slice(s) = mat_old;
+      repeats(0)++;
     }
-
+    
     bics(s) = old_bic;
 
     if(repeats(0) > stop_early){
+      Rcpp::Rcout << "Stopping early at iteration " << s << std::endl;
       break;
-    }
+    } 
+    
   }
 
   Rcpp::List ret;
